/*
    TiMidity -- Experimental MIDI to WAVE converter
    Copyright (C) 1995 Tuukka Toivonen <titoivon@snakemail.hut.fi>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

/* Filename extension, followed by command to run decompressor so that
   output is written to stdout. Terminate the list with 0.
   Any file with a name ending in one of these strings will be run
   through the corresponding decompressor. If you don't like this
   behavior, you can comment this out to disable automatic
   decompression entirely. */
#define DECOMPRESSOR_LIST { \
			     ".gz", "gunzip -c %s", \
			     ".Z", "zcat %s", \
			     ".zip", "unzip -p %s", \
			     ".lha", "lha -pq %s", \
			     ".lzh", "lha -pq %s", \
			     ".sht", "shorten -x %s", \
			     0 }

/* Acoustic Grand Piano seems to be the usual default instrument. */
#define DEFAULT_PROGRAM 0

/* 9 here is MIDI channel 10, which is the standard percussion channel.
   Some files (notably C:\WINDOWS\CANYON.MID) think that 16 is one too. 
   On the other hand, some files know that 16 is not a drum channel and
   try to play music on it. This really should be a runtime option. */
/* #define ISDRUMCHANNEL(x) ((x)==9 || (x)==15) */
#define ISDRUMCHANNEL(x) ((x)==9)

/* The default PCM device to play on. */
#define AUDIO_DEVICE		"/dev/dsp"

/* Default sampling rate, default polyphony, and maximum polyphony.
   These can all be overridden from the command line. */
#define DEFAULT_RATE	32000
#define DEFAULT_VOICES	32
#define MAX_VOICES	32

/* A somewhat arbitrary frequency range. The low end of this will
   sound terrible as no lowpass filtering whatever is performed on the
   data before resampling. The high end could have trouble if
   pitch-related computations start overflowing. */ 
#define MIN_OUTPUT_RATE 	4000
#define MAX_OUTPUT_RATE 	65000

/* In percent. */
#define DEFAULT_AMPLIFICATION 	100

/* The size of the internal buffer is 2^AUDIO_BUFFER_BITS samples.
   This determines maximum number of samples ever computed in a row.
   For the Linux sound driver, it also specifies the size of the
   buffer fragment -- a smaller fragment gives a faster response in
   interactive mode. 10 is probably a good number. */
#define AUDIO_BUFFER_BITS 10

/* 1000 here will give a control ratio of 22:1 with 22 kHz output.
   Higher CONTROLS_PER_SECOND values allow more accurate rendering
   of envelopes. The cost is CPU time. */
#define CONTROLS_PER_SECOND 1000

/* Recommended. This option increases CPU usage by half, but without
   it sound quality is very poor. */
#define LINEAR_INTERPOLATION

/* How many bits to use for the fractional part of sample positions.
   This affects tonal accuracy. The entire position counter must fit
   in 32 bits, so with FRACTION_BITS equal to 12, the maximum size of
   a sample is 1048576 samples (2 megabytes in memory). If you think
   timidity is out of tune, increasing this might help, especially if
   you play low notes at high sampling rates. */
#define FRACTION_BITS 12

/**********************************************************************/
/* Anything below this shouldn't need to be changed */

#define INTEGER_BITS (32 - FRACTION_BITS)
#define INTEGER_MASK (0xFFFFFFFF << FRACTION_BITS)
#define FRACTION_MASK (~ INTEGER_MASK)

/* This is enforced by some computations that must fit in an int */
#define MAX_CONTROL_RATIO 255

/* This has to be a power of two to allow the use of DSP fragments
   under Linux */
#define AUDIO_BUFFER_SIZE (1<<AUDIO_BUFFER_BITS)

/* Byte order */
#ifdef LINUX
#define LITTLE_ENDIAN
#endif

/* Instrument files are little-endian, MIDI files big-endian. */
#define XCHG_SHORT(x) ((((x)&0xFF)<<8) | (((x)>>8)&0xFF))
#define XCHG_LONG(x) ((((x)&0xFF)<<24) | \
		      (((x)&0xFF00)<<8) | \
		      (((x)&0xFF0000)>>8) | \
		      (((x)>>24)&0xFF))

#ifdef LITTLE_ENDIAN
#define LE_SHORT(x) x
#define LE_LONG(x) x
#define BE_SHORT(x) XCHG_SHORT(x)
#define BE_LONG(x) XCHG_LONG(x)
#else
#define BE_SHORT(x) x
#define BE_LONG(x) x
#define LE_SHORT(x) XCHG_SHORT(x)
#define LE_LONG(x) XCHG_LONG(x)
#endif

#define MAX_AMPLIFICATION 800

/* Some instruments click when retriggered. This is a hack to
   alleviate the symptoms. Fixing the problem later. Apparently this
   also messes up the note display. Let's see if anyone complains
   about the clicks first. */
/* #define FOWL_PLAY_CLICK */

/* You could specify a complete path, e.g. "/etc/timidity.cfg", and
   then specify the library directory in the configuration file. */
#define CONFIG_FILE	"timidity.cfg"
