/*

    TiMidity -- Experimental MIDI to WAVE converter
    Copyright (C) 1995 Tuukka Toivonen <titoivon@snakemail.hut.fi>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

   playmidi.h

   */

typedef struct {
  unsigned long time;
  unsigned char channel, type, a, b;
} MidiEvent;

/* Midi events */
#define ME_NONE 	0
#define ME_NOTEON	1
#define ME_NOTEOFF	2
#define ME_KEYPRESSURE	3
#define ME_MAINVOLUME	4
#define ME_PAN		5
#define ME_SUSTAIN	6
#define ME_EXPRESSION	7
#define ME_PITCHWHEEL	8
#define ME_PROGRAM	9
#define ME_TEMPO	10

/* I don't know how this parameter should be interpreted :( */
#define ME_PITCH_SENS	11

/* I don't know what the event for switching banks looks like :< */
#define ME_TONE_BANK	12

#define ME_EOT		99

typedef struct {
  int
    bank, program, volume, sustain, panning, pitchbend, expression;
} Channel;

/* Causes the instrument's default panning to be used. */
#define NO_PANNING -1

typedef struct {
  unsigned char
    status, channel, note, velocity;
  Sample *sample;
  int
    orig_frequency, frequency;
  unsigned long
    sample_offset;
  int
    sample_increment;
  int 
    envelope_stage, envelope_volume, envelope_target, envelope_increment,
    control_counter, left_amp, right_amp, left_envelope, right_envelope,
    /* What you get for trying to save a few imull's */
    panning, panned;
} Voice;

/* Voice status options: */
#define VOICE_FREE 0
#define VOICE_ON 1
#define VOICE_SUSTAINED 2
#define VOICE_OFF 3

/* Voice panned options: */
#define PANNED_MYSTERY 0
#define PANNED_LEFT 1
#define PANNED_RIGHT 2
#define PANNED_CENTER 3
/* Anything but PANNED_MYSTERY only uses the left volume */

extern Channel channel[16];
extern Voice voice[MAX_VOICES];

extern int control_ratio, amp_with_poly, amplification, voices;
extern char *audio_name;

extern int dump_midi(MidiEvent *el, int events);
extern int play_midi(MidiEvent *el, int events, int samples);
