.TH TiMidity 1 "18 Feb 1995" \" -*-nroff-*-
.SH NAME
TiMidity \- MIDI to WAVE converter and player
.P
.SH SYNOPSIS
.B timidity
[\-options] filename [filenames ...]
.P
.SH DESCRIPTION
TiMidity is a MIDI to WAVE converter that uses Gravis
Ultrasound\-compatible patch files to generate digital audio data
from General MIDI files. The audio data can be played through any
PCM\-capable sound card; with a fast computer, this can be done in real
time. TiMidity is an experimental program and it currently only
runs under Linux.
.P
.SH OPTIONS
.TP
.BI \-s " frequency"
Sets the sampling (output) frequency. Not all sound devices are
capable of all frequencies.
.TP
.BI \-M
Specifies monophonic output. This can reduce CPU requirements by up to
50%.
.TP
.BI \-8
Forces 8\-bit output. This is not generally a good idea, as the
noise\-to\-signal ratio gets a bit excessive, but the option is
there.
.TP
.BI \-d " device"
Instructs TiMidity to use another PCM (``dsp'') device.
.TP
.BI \-o " file"
Outputs raw PCM data to \fIfile\fP. Messages will be printed to stderr.
Use ``\-'' as filename to direct output to stdout.
.TP
.BI \-W " file"
As \fB\-o\fP, but inserts a Microsoft WAVE header at the beginning of
\fIfile\fP. The header is probably invalid as it contains 0xFFFFFFFF
for RIFF and data block lengths. Still, \fIsox\fP can read these
files, so you can convert them to something else without having to
specify sampling rates, widths, and channels.
.TP
.BI \-p " voices"
Sets the polyphony (maximum number of simultaneous voices) to
\fIvoices\fP.
.TP
.BI \-A " amplification"
Multiplies the master volume by \fIamplification\fP%.
.TP
.BI \-C " ratio"
Sets the ratio of sampling and control frequencies. This determines how
often envelopes are recalculated -- small ratios yield better quality
but use more CPU time.
.TP
.BI \-L " directory"
Adds \fIdirectory\fP to the library path. Patch, configuration, and
MIDI files are searched along this path. Directories added last will
be searched first. Note that the current directory is always searched
first before the library path.
.TP
.BI \-c " file"
Reads an extra configuration file. 
.TP
.BI \-I " number"
Uses the program \fInumber\fP as the default instrument. Any Program
Change events in MIDI files will override this option.
.TP
.BI \-P " file"
Uses the patch \fIfile\fP for every program except drums. Program
Change events will be ignored. This is useful for testing new
patches.
.TP 
.BI \-U
Instructs TiMidity to unload all instruments from memory between
MIDI files. This can reduce memory requirements when playing many
files in succession.
.TP
.BI \-v
Increases verbosity. This option is cumulative.
.TP
.BI \-q
Decreases verbosity. This option is cumulative.
.TP
.BI \-i
Selects interactive mode, if compiled in.  See the section KEYS for a
list of available commands in interactive mode.
.P
\fBNOTE:\fP
In this mode, audio data is computed ahead for only a small
fraction of a second, to enable near real\-time response to user
commands.  If the CPU is held busy by other tasks for more than that
small fraction of a second, the sound will be cut off.  Ideally,
TiMidity should be the only program running, but since this is rarely
possible, you can use the \fB\-B\fP option to increase the buffer size
(and response lag).
.TP
.BI \-B " fragments"
Selects the number of buffer fragments in interactive mode. Increasing
the number of buffers may reduce choppiness when many processes are
running. It will make TiMidity seem to respond sluggishly to fast
forward, rewind, and volume controls, and throw the status display off
sync. Specify a \fIfragments\fP of 0 to use the maximum number of
fragments available.
.P
.SH KEYS
The following keyboard commands are available in interactive mode:
.TP
.BI V
Increase volume.
.TP
.BI v
Decrease volume.
.TP
.BI b
Skip back.
.TP
.BI f
Skip forward.
.TP
.BI n
Play the next file.
.TP
.BI p
Play the previous file.
.TP
.BI r
Restart the current file.
.TP
.BI q
Quit TiMidity.
.TP
.BI h
Toggle the help display.
.P
.SH FILES
TiMidity looks for the configuration file \fItimidity.cfg\fP at
startup, before processing any options. If it can't be accessed, and
the library path is changed with a \fB\-L\fP option on the command
line, then the default file will be sought again along the new library
path after processing all options, unless another configuration file was
specified with the \fB\-c\fP option. 
.P
Configuration files define the mapping of MIDI programs to instrument
files. Multiple files may be specified, and statements in later ones
will override earlier ones. The following statements can be used in a
configuration file:
.TP
.BI dir " directory"
Adds \fIdirectory\fP to the search path in the same manner as the
\fB\-L\fP command line option.
.TP
.BI source " file"
Reads another configuration file, then continues processing the
current one.
.TP
.BI bank " number"
Selects the tone bank to modify. Patch mappings that follow will
affect this tone bank.
.TP
.BI drumset " number"
Selects the drum set to modify. Patch mappings that follow will affect
this drum set.
.TP
.I "number file"
Specifies that the the MIDI program \fInumber\fP in the current tone
bank or drum set should be played using the patch \fIfile\fP.
.P
\fBNOTE:\fP Whenever any filename ends in one of the compiled\-in
compression identifiers, such as \fI.gz\fP, or \fI.sht\fP, TiMidity
will pipe the file through the appropriate decompressor. MIDI files
often compress very well, so the ability to handle compressed files
can be useful.
The special filename ``\-'' can be used on the command line to
indicate that a MIDI file should be read from stdin.
.P
.SH COPYRIGHT
Copyright (C) 1995 Tuukka Toivonen. 

TiMidity is free software; you can redistribute it
and/or modify it under the terms of the \fIGNU General Public
License\fP as published by the Free Software Foundation; either
version 2 of the License, or (at your option) any later version.

TiMidity is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
\fIGNU General Public License\fP for more details.
.SH AVAILABILITY
The latest release is available on the TiMidity Home Page,
URL \fIhttp://www.hut.fi/~titoivon/timidity\fP.
.SH BUGS
.SH AUTHOR
Tuukka Toivonen <titoivon@snakemail.hut.fi>
